Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-foss.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'spec/graphql/mutations/design_management/delete_spec.rb')
-rw-r--r--spec/graphql/mutations/design_management/delete_spec.rb31
1 files changed, 17 insertions, 14 deletions
diff --git a/spec/graphql/mutations/design_management/delete_spec.rb b/spec/graphql/mutations/design_management/delete_spec.rb
index 93fff5e5103..79196d4965d 100644
--- a/spec/graphql/mutations/design_management/delete_spec.rb
+++ b/spec/graphql/mutations/design_management/delete_spec.rb
@@ -86,9 +86,11 @@ RSpec.describe Mutations::DesignManagement::Delete do
end
end
- it 'runs no more than 29 queries' do
+ it 'runs no more than 30 queries' do
+ allow(Gitlab::Tracking).to receive(:event) # rubocop:disable RSpec/ExpectGitlabTracking
+
filenames.each(&:present?) # ignore setup
- # Queries: as of 2021-07-22
+ # Queries: as of 2022-06-15
# -------------
# 01. routing query
# 02. find project by id
@@ -106,20 +108,21 @@ RSpec.describe Mutations::DesignManagement::Delete do
# 15. current designs by filename and issue
# 16, 17 project.authorizations for user (same query as 5)
# 18. find route by id and source_type
+ # 19. find plan for standard context
# ------------- our queries are below:
# 19. start transaction 1
# 20. start transaction 2
# 21. find version by sha and issue
# 22. exists version with sha and issue?
# 23. leave transaction 2
# 24. create version with sha and issue
# 25. create design-version links
# 26. validate version.actions.present?
# 27. validate version.issue.present?
# 28. validate version.sha is unique
# 29. leave transaction 1
#
- expect { run_mutation }.not_to exceed_query_limit(29)
+ expect { run_mutation }.not_to exceed_query_limit(30)
end
end
@@ -106,20 +108,21 @@ RSpec.describe Mutations::DesignManagement::Delete do
# ------------- our queries are below:
- # 19. start transaction 1
- # 20. start transaction 2
- # 21. find version by sha and issue
- # 22. exists version with sha and issue?
- # 23. leave transaction 2
- # 24. create version with sha and issue
- # 25. create design-version links
- # 26. validate version.actions.present?
- # 27. validate version.issue.present?
- # 28. validate version.sha is unique
- # 29. leave transaction 1
+ # 20. start transaction 1
+ # 21. start transaction 2
+ # 22. find version by sha and issue
+ # 23. exists version with sha and issue?
+ # 24. leave transaction 2
+ # 25. create version with sha and issue
+ # 26. create design-version links
+ # 27. validate version.actions.present?
+ # 28. validate version.issue.present?
+ # 29. validate version.sha is unique
+ # 30. leave transaction 1
#